#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 setenv
version:              0.1.1.3
visibility:           public
id:                   setenv-0.1.1.3-ADyKsIah1zg4WlxP7oqCU1
key:                  setenv-0.1.1.3-ADyKsIah1zg4WlxP7oqCU1
license:              MIT
copyright:            (c) 2012-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A cross-platform library for setting environment variables
description:
    A cross-platform library for setting environment variables

    Note: Since @base- 4.7.0.0@ the functions @setEnv@ and
    @unsetEnv@ are provided by @System.Environment@.
    @System.SetEnv@ merily re-exports those functions when built
    with @base >= 4.7@.

category:             System
abi:                  c7c31b7c31b857aa7e53c98732fc2c35
exposed:              True
exposed-modules:      System.SetEnv
import-dirs:          /usr/lib/ghc-8.10.5/site-local/setenv-0.1.1.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/setenv-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/setenv-0.1.1.3
hs-libraries:         HSsetenv-0.1.1.3-ADyKsIah1zg4WlxP7oqCU1
depends:              base-4.14.2.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-setenv/html/setenv.haddock
haddock-html:         /usr/share/doc/haskell-setenv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

